<?php
/**
 * Plugin Name: AstroPay for WooCommerce
 * Plugin URI: https://astropay.com
 * Description: This plugin integrates AstroPay API with WooCommerce for Asia, Africa and Latin America.
 * Author: AstroPay
 * Author URI: https://astropay.com
 * Version: 1.0.1
 * Text Domain: astropay
 * Domain Path: /languages
 * Requires at least: 3.8
 * Tested up to: 5.7
 * WC requires at least: 3.0
 * WC tested up to: 5.1.0
 */

// WooCommerce is required for the plugin
if ( in_array('woocommerce/woocommerce.php', (array) get_option( 'active_plugins', array() ) ) ) {
	// Init AstroPay Gateway after WooCommerce has loaded
	add_action( 'plugins_loaded', 'init_astropay_gateway', 0 );
}

/**
 * init_astropay_gateway function.
 *
 * @description Initializes the gateway.
 * @access public
 * @return void
 */
function init_astropay_gateway() {
	// If the WooCommerce payment gateway class is not available, do nothing
	if ( ! class_exists( 'WC_Payment_Gateway' ) ) return;

	// Localization
	load_plugin_textdomain( 'astropay', false, basename( dirname( __FILE__ ) ) . '/languages/' );

	// Core class for Payment gateway
	require_once( plugin_basename( 'classes/wc-gateway-astropay.php' ) );

	// Add the gateway to list of available gateways
	add_filter( 'woocommerce_payment_gateways', 'add_astropay_gateway' );

	/**
	 * add_gateway()
	 *
	 * Register the gateway within WooCommerce.
	 *
	 * @since 1.0.0
	 * @param array	methods	available payment gateway methods
	 * @return array
	 */
	function add_astropay_gateway( $methods ) {
		$methods[] = 'WC_Gateway_AstroPay';
		return $methods;
	}
}
